@@ -86,3 +86,10 @@ def test_pip_import(venv):
     """
     cmd = ['python', '-c', 'import pip']
     popen_text(venv.run)(cmd)
+
+
+def test_distutils_has_origin():
+    """
+    Distutils module spec should have an origin. #2990.
+    """
+    assert __import__('distutils').__spec__.origin
